function D = EuclideanDistance(X,P)

%Compute the euclidean distance from X to P
%
% EuclideanDistance(X,P) returns the Euclidean distance of each row of X to the 
%       first row of P
%
% PARAMETERS:
%   X ~ Positions
%   P ~ Reference Position

% Copyright 2012, Xavier Alameda-Pineda
% INRIA Grenoble Rhône-Alpes
% E-mail: xavi.alameda@gmail.com
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    %%% Check the input
    % The dimension of both vectors should be the same
    if(size(X,2)~=size(P,2))
        error('X and P should have the same number of columns.');
    end
    % There should be just one microphone position
    if(size(P,1)~=1)
        fprintf('[EuclideanDistance Warning]: Computing the distance to the first row of MIC.');
    end

    %%% Compute the distance of every row on X to the first row of MIC
    D = sqrt(sum(bsxfun(@minus,X,P(1,:)).^2,2));
    
return
