function Positions = GenerateIcosahedron(radius)

%Generate the vertices of an icosahedron
%
% USAGE: Position = GenerateIcosahedron(radius)
%
% PARAMETERS:
%   radius ~ radious of the icosahedron
%
% RETURN:
%   Positions ~ the positions of the vertices
%

% Copyright (c) 2009 Peter Kovesi
% Centre for Exploration Targeting
% The University of Western Australia
% peter.kovesi at uwa edu au
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    % Golden ratio
    phi = (1+sqrt(5))/2;
    Positions = [0   1  phi 
                 0  -1  phi 
                 0   1 -phi 
                 0  -1 -phi 
                 1  phi  0  
                -1  phi  0  
                 1 -phi  0  
                -1 -phi  0  
                phi  0   1  
               -phi  0   1  
                phi  0  -1  
               -phi  0  -1];

    % Scale to required radius
    Positions = Positions*radius/(sqrt(1+phi^2));
    
end
