function [foundTDEs, experimentOptions, errorTDEs, localization] = PrepareRealData2Plot(resultNames)

% Copyright 2012, Xavier Alameda-Pineda
% INRIA Grenoble Rhône-Alpes
% E-mail: xavi.alameda@gmail.com
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    [~, hostname] = system('hostname');
    if strcmp(hostname(1:end-1),'peirasmos')
        rootDir = '/local_home/alamedap/Software/';
    elseif strcmp(hostname(1:end-1),'cassiopeia'),
        rootDir = '/local_scratch/alamedap/Software/';
    else
        rootDir = '/scratch/cassiopeia/alamedap/Software/';
    end
    rootDir = strcat(rootDir,'gtde/trunk/results/');

    %%% Load results
    resultsTDE = cell(0);
    resultserrorTDE = cell(0);
    resultsLoc = cell(0);
    fileNames = cell(0);
    usedMethod = cell(0);
    for d = 1:numel(resultNames)
        % Load file
        fileLoad = load(strcat(rootDir,resultNames{d}));
        % ExperimentOptions
        experimentOptions = fileLoad.experimentOptions;
        % Method name
        methodName = experimentOptions.methodOptions.type;
        % Store results
        resultsTDE = cat(1,resultsTDE,{fileLoad.foundTDEs(:,:)});
        resultserrorTDE = cat(1,resultserrorTDE,{fileLoad.errorTDEs(:,:)});
        resultsLoc = cat(1,resultsLoc,{fileLoad.localization(:,:)});
        fileNames = cat(1,fileNames,strcat(rootDir,resultNames{d}));
        % Store used method
        usedMethod = cat(1,usedMethod,methodName);
    end
    % The same with the methods
%     [usedMethod, IC, IA] = unique(usedMethod);
    nMethod = numel(usedMethod);

    % Correct experiment options
    experimentOptions.method = usedMethod;

    % Number of positions and signals
    [nSignals, nPositions] = size(resultsTDE{1});

    foundTDEs = cell(nSignals,nPositions,nMethod);
    errorTDEs = cell(nSignals,nPositions,nMethod);
    localization = cell(nSignals,nPositions,nMethod);
    % Save the results in the right place
    for sMethod = 1:nMethod,
        foundTDEs(:,:,sMethod) = resultsTDE{sMethod};
        errorTDEs(:,:,sMethod) = resultserrorTDE{sMethod};
        localization(:,:,sMethod) = resultsLoc{sMethod};
    end
    
end

% 
% 
% figure
% plot3(experimentOptions.sourcePositions(:,1),experimentOptions.sourcePositions(:,2),experimentOptions.sourcePositions(:,3),'ko');
% hold on
% plot3(experimentOptions.microphonePositions(:,1),experimentOptions.microphonePositions(:,2),experimentOptions.microphonePositions(:,3),'rx');
%      
% 
% %%% Run the batch
% showResultsTDEExperiments(experimentOptions,foundTDEs);