function [foundTDEs, experimentOptions, errorTDEs, localization] = PrepareSphericalData2Plot(resultNames)

% Copyright 2012, Xavier Alameda-Pineda
% INRIA Grenoble Rhône-Alpes
% E-mail: xavi.alameda@gmail.com
% 
% This is part of the gtde program.
% 
% gtde is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    [~, hostname] = system('hostname');
    if strcmp(hostname(1:end-1),'peirasmos')
        rootDir = '/local_home/alamedap/Software/';
    elseif strcmp(hostname(1:end-1),'cassiopeia'),
        rootDir = '/local_scratch/alamedap/Software/';
    else
        rootDir = '/scratch/cassiopeia/alamedap/Software/';
    end
    rootDir = strcat(rootDir,'gtde/trunk/results/');

    %%% Load results
    resultsTDE = cell(0);
    resultserrorTDE = cell(0);
    resultsLoc = cell(0);
    fileNames = cell(0);
    usedT60SNRMethod = cell(3,0);
    usedT60 = zeros(0);
    usedSNR = zeros(0);
    usedMethod = cell(0);
    for d = 1:numel(resultNames)
        % Load file
        fileLoad = load(strcat(rootDir,resultNames{d}));
        % ExperimentOptions
        experimentOptions = fileLoad.experimentOptions;
        % Method name
        methodName = experimentOptions.methodOptions.type;
        for sT60 = 1:numel(experimentOptions.dataOptions.t60),
            % Retrieve t60 value
            t60V = fileLoad.experimentOptions.dataOptions.t60(sT60);
            for sSNR = 1:numel(experimentOptions.dataOptions.snrValues),
                % Retrieve snr value
                snrV = experimentOptions.dataOptions.snrValues(sSNR);
                % Store results
                resultsTDE = cat(1,resultsTDE,{fileLoad.foundTDEs(:,:,sSNR,sT60)});
                resultserrorTDE = cat(1,resultserrorTDE,{fileLoad.errorTDEs(:,:,sSNR,sT60)});
                resultsLoc = cat(1,resultsLoc,{fileLoad.localization(:,:,sSNR,sT60)});
                fileNames = cat(1,fileNames,strcat(rootDir,resultNames{d}));
                % Store used T60 and used SNR
                usedT60 = cat(1,usedT60,t60V);
                usedSNR = cat(1,usedSNR,snrV);
                usedMethod = cat(1,usedMethod,methodName);
                % Fill the unique variable
                usedT60SNRMethod = cat(2,usedT60SNRMethod,{t60V,snrV,methodName}');
            end
        end
    end
    % Know for which expeirment was used each value of t60
    [usedT60] = unique(usedT60);
    nT60 = numel(usedT60);
    % Know for which expeirment was used each value of snr
    [usedSNR] = unique(usedSNR);
    nSNR = numel(usedSNR);
    % The same with the methods
    [usedMethod] = unique(usedMethod);
    nMethod = numel(usedMethod);

    % Correct experiment options
    experimentOptions.snrValues = usedSNR;
    experimentOptions.T60 = usedT60;
    experimentOptions.method = usedMethod;

    % Number of positions and signals
    [nSignals, nPositions] = size(resultsTDE{1});

    foundTDEs = cell(nSignals,nPositions,nSNR,nT60,nMethod);
    errorTDEs = cell(nSignals,nPositions,nSNR,nT60,nMethod);
    localization = cell(nSignals,nPositions,nSNR,nT60,nMethod);
    % Save the results in the right place
    remappingResultsError = false;
    for sT60 = 1:nT60,
        for sSNR = 1:nSNR
            for sMethod = 1:nMethod,
                index = find( [usedT60SNRMethod{1,:}] == usedT60(sT60) & [usedT60SNRMethod{2,:}] == usedSNR(sSNR) & strcmp(usedT60SNRMethod(3,:),usedMethod{sMethod}) );
                if isempty(index)
                    fprintf('The combination T60=%f SNR=%f Method=%s does not correspond to any file.\n',usedT60(sT60),usedSNR(sSNR),usedMethod{sMethod});
                    remappingResultsError = true;
                elseif numel(index) > 1
                    fprintf('Files:\n');
                    for ii = 1:numel(index),
                        fprintf('%s\n',fileNames{index(ii)});
                    end
                    fprintf('shared the same parameters, T60=%f, SNR=%f and Method=%s\n.',usedT60(sT60),usedSNR(sSNR),usedMethod{sMethod});
                    remappingResultsError = true;
                else
                    foundTDEs(:,:,sSNR,sT60,sMethod) = resultsTDE{index};
                    errorTDEs(:,:,sSNR,sT60,sMethod) = resultserrorTDE{index};
                    localization(:,:,sSNR,sT60,sMethod) = resultsLoc{index};
                end
            end
        end
    end
    
end

% 
% 
% figure
% plot3(experimentOptions.sourcePositions(:,1),experimentOptions.sourcePositions(:,2),experimentOptions.sourcePositions(:,3),'ko');
% hold on
% plot3(experimentOptions.microphonePositions(:,1),experimentOptions.microphonePositions(:,2),experimentOptions.microphonePositions(:,3),'rx');
%      
% 
% %%% Run the batch
% showResultsTDEExperiments(experimentOptions,foundTDEs);